==> gerbil-0.15.1.tgz: gerbil/lib/static/std__generic__builtin.scm <==
(declare (block) (standard-bindings) (extended-bindings))
(begin
  (define std/generic/builtin#<type>::t ##type-type)
  (define std/generic/builtin#<exception>::t (macro-type-exception))
  (define std/generic/builtin#<hash-table>::t (##structure-type (make-table)))
  (define std/generic/builtin#<time>::t (macro-type-time))
  (define std/generic/builtin#<thread>::t (macro-type-thread))
  (define std/generic/builtin#<thread-group>::t (macro-type-tgroup))
  (define std/generic/builtin#<mutex>::t (macro-type-mutex))
  (define std/generic/builtin#<condvar>::t (macro-type-condvar))
  (define std/generic/builtin#<port>::t (macro-type-port))
  (define std/generic/builtin#<object-port>::t (macro-type-object-port))
  (define std/generic/builtin#<character-port>::t (macro-type-character-port))
  (define std/generic/builtin#<byte-port>::t (macro-type-byte-port))
  (define std/generic/builtin#<device-port>::t (macro-type-device-port))
  (define std/generic/builtin#<vector-port>::t (macro-type-vector-port))
  (define std/generic/builtin#<string-port>::t (macro-type-string-port))
  (define std/generic/builtin#<u8vector-port>::t (macro-type-u8vector-port))
  (define std/generic/builtin#<raw-device-port>::t
    (macro-type-raw-device-port))
  (define std/generic/builtin#<tcp-server-port>::t
    (macro-type-tcp-server-port))
  (define std/generic/builtin#<directory-port>::t (macro-type-directory-port))
  (define std/generic/builtin#<event-queue-port>::t
    (macro-type-event-queue-port))
  (define std/generic/builtin#<readtable>::t (macro-type-readtable)))

==> gerbil-0.16.tgz: gerbil/lib/static/std__generic__builtin.scm <==
(declare (block) (standard-bindings) (extended-bindings))
(begin
  (define std/generic/builtin#<type>::t ##type-type)
  (define std/generic/builtin#<exception>::t (macro-type-exception))
  (define std/generic/builtin#<hash-table>::t
    (let ((__tmp3998 (make-table)))
      (declare (not safe))
      (##structure-type __tmp3998)))
  (define std/generic/builtin#<time>::t (macro-type-time))
  (define std/generic/builtin#<thread>::t (macro-type-thread))
  (define std/generic/builtin#<thread-group>::t (macro-type-tgroup))
  (define std/generic/builtin#<mutex>::t (macro-type-mutex))
  (define std/generic/builtin#<condvar>::t (macro-type-condvar))
  (define std/generic/builtin#<port>::t (macro-type-port))
  (define std/generic/builtin#<object-port>::t (macro-type-object-port))
  (define std/generic/builtin#<character-port>::t (macro-type-character-port))
  (define std/generic/builtin#<byte-port>::t (macro-type-byte-port))
  (define std/generic/builtin#<device-port>::t (macro-type-device-port))
  (define std/generic/builtin#<vector-port>::t (macro-type-vector-port))
  (define std/generic/builtin#<string-port>::t (macro-type-string-port))
  (define std/generic/builtin#<u8vector-port>::t (macro-type-u8vector-port))
  (define std/generic/builtin#<raw-device-port>::t
    (macro-type-raw-device-port))
  (define std/generic/builtin#<tcp-server-port>::t
    (macro-type-tcp-server-port))
  (define std/generic/builtin#<directory-port>::t (macro-type-directory-port))
  (define std/generic/builtin#<event-queue-port>::t
    (macro-type-event-queue-port))
  (define std/generic/builtin#<readtable>::t (macro-type-readtable)))
